import kotlin.math.sin
import kotlin.time.*
import kotlin.time.TimeSource.*

@OptIn(ExperimentalTime::class)
fun main() {
    // Zeitmessung mit Monotonic
    val now = Monotonic.markNow()
    for(i in (0..1_000_000)) {
        val x = sin(i.toDouble())
    }
    val dur = now.elapsedNow()
    println("Zeitspanne: $dur")    // Ausgabe z. B.  75.2 ms

    // Zeitspannen angeben und vergleichen
    if (dur > Duration.milliseconds(100))
        println("Es hat länger als 100 Millisekunden gedauert.")

    // Rechnen mit Zeitspannen
    val myDur = Duration.minutes(2) + Duration.seconds(3) - Duration.milliseconds(10) * 0.66
    println(myDur)                       // 123s (gerundet)
    println(myDur.inWholeMilliseconds)   // 122970 (exakt)

    // Zeitmessung mit measureTime
    val dur2 = measureTime {
        for(i in (1..1_000_000)) {
            val x = sin(i.toDouble())
        }
    }
    println("Zeit:     $dur2")

    // Zeitmessung mit measureTimeValue
    val (result, dur3) = measureTimedValue {
        var sum = 0.0
        for(i in (1..1_000_000)) {
            sum += sin(i.toDouble())
        }
        sum
    }
    println("Zeit:     $dur3")




}